Struct vonuvoli_scheme::internals::values::ArrayImmutable [−][src]
pub struct ArrayImmutable(_);
Methods
impl ArrayImmutable[src]
impl ArrayImmutablepub fn from_rc(rc: StdRc<StdBox<[Value]>>) -> ArrayImmutable[src]
pub fn from_rc(rc: StdRc<StdBox<[Value]>>) -> ArrayImmutablepub fn clone_rc(rc: &StdRc<StdBox<[Value]>>) -> ArrayImmutable[src]
pub fn clone_rc(rc: &StdRc<StdBox<[Value]>>) -> ArrayImmutablepub fn is_self(&self, other: &ArrayImmutable) -> bool[src]
pub fn is_self(&self, other: &ArrayImmutable) -> boolpub fn array_ref(&self) -> ArrayRef[src]
pub fn array_ref(&self) -> ArrayRefpub fn values_rc_clone(&self) -> StdRc<StdBox<[Value]>>[src]
pub fn values_rc_clone(&self) -> StdRc<StdBox<[Value]>>pub fn to_mutable(&self) -> ArrayMutable[src]
pub fn to_mutable(&self) -> ArrayMutableTrait Implementations
impl StdAsRef<ArrayImmutable> for ArrayImmutable[src]
impl StdAsRef<ArrayImmutable> for ArrayImmutablefn as_ref(&self) -> &ArrayImmutable[src]
fn as_ref(&self) -> &ArrayImmutablePerforms the conversion.
impl StdFrom<ArrayImmutable> for Value[src]
impl StdFrom<ArrayImmutable> for Valuefn from(value: ArrayImmutable) -> Value[src]
fn from(value: ArrayImmutable) -> ValuePerforms the conversion.
impl StdFrom<ArrayImmutable> for StdBox<Value>[src]
impl StdFrom<ArrayImmutable> for StdBox<Value>ⓘImportant traits for Box<R>fn from(value: ArrayImmutable) -> StdBox<Value>[src]
fn from(value: ArrayImmutable) -> StdBox<Value>Performs the conversion.
impl StdInto0<Outcome<Value>> for ArrayImmutable[src]
impl StdInto0<Outcome<Value>> for ArrayImmutableimpl StdFrom<ArrayImmutable> for Expression[src]
impl StdFrom<ArrayImmutable> for Expressionfn from(value: ArrayImmutable) -> Expression[src]
fn from(value: ArrayImmutable) -> ExpressionPerforms the conversion.
impl StdFrom<ArrayImmutable> for StdBox<Expression>[src]
impl StdFrom<ArrayImmutable> for StdBox<Expression>ⓘImportant traits for Box<R>fn from(value: ArrayImmutable) -> StdBox<Expression>[src]
fn from(value: ArrayImmutable) -> StdBox<Expression>Performs the conversion.
impl StdInto0<Outcome<Expression>> for ArrayImmutable[src]
impl StdInto0<Outcome<Expression>> for ArrayImmutablefn into_0(self) -> Outcome<Expression>[src]
fn into_0(self) -> Outcome<Expression>impl StdTryFrom<Value> for ArrayImmutable[src]
impl StdTryFrom<Value> for ArrayImmutabletype Error = Error
try_from)The type returned in the event of a conversion error.
fn try_from(value: Value) -> Result<ArrayImmutable, Error>[src]
fn try_from(value: Value) -> Result<ArrayImmutable, Error>try_from)Performs the conversion.
impl StdTryAsRef0<ArrayImmutable> for Value[src]
impl StdTryAsRef0<ArrayImmutable> for Valuetype Error = Error
fn try_as_ref_0(&self) -> Result<&ArrayImmutable, Error>[src]
fn try_as_ref_0(&self) -> Result<&ArrayImmutable, Error>impl StdTryFrom<StdBox<Value>> for ArrayImmutable[src]
impl StdTryFrom<StdBox<Value>> for ArrayImmutabletype Error = Error
try_from)The type returned in the event of a conversion error.
fn try_from(value: StdBox<Value>) -> Result<ArrayImmutable, Error>[src]
fn try_from(value: StdBox<Value>) -> Result<ArrayImmutable, Error>try_from)Performs the conversion.
impl StdTryFrom<Expression> for ArrayImmutable[src]
impl StdTryFrom<Expression> for ArrayImmutabletype Error = Error
try_from)The type returned in the event of a conversion error.
fn try_from(value: Expression) -> Result<ArrayImmutable, Error>[src]
fn try_from(value: Expression) -> Result<ArrayImmutable, Error>try_from)Performs the conversion.
impl StdTryFrom<StdBox<Expression>> for ArrayImmutable[src]
impl StdTryFrom<StdBox<Expression>> for ArrayImmutabletype Error = Error
try_from)The type returned in the event of a conversion error.
fn try_from(value: StdBox<Expression>) -> Result<ArrayImmutable, Error>[src]
fn try_from(value: StdBox<Expression>) -> Result<ArrayImmutable, Error>try_from)Performs the conversion.
impl Display for ArrayImmutable[src]
impl Display for ArrayImmutablefn fmt(&self, formatter: &mut Formatter) -> Result[src]
fn fmt(&self, formatter: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl HashValue for ArrayImmutable[src]
impl HashValue for ArrayImmutableimpl Hash for ArrayImmutable[src]
impl Hash for ArrayImmutablefn hash<Hasher: Hasher>(&self, hasher: &mut Hasher)[src]
fn hash<Hasher: Hasher>(&self, hasher: &mut Hasher)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Eq for ArrayImmutable[src]
impl Eq for ArrayImmutableimpl PartialEq for ArrayImmutable[src]
impl PartialEq for ArrayImmutablefn eq(&self, other: &ArrayImmutable) -> bool[src]
fn eq(&self, other: &ArrayImmutable) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Ord for ArrayImmutable[src]
impl Ord for ArrayImmutablefn cmp(&self, other: &ArrayImmutable) -> Ordering[src]
fn cmp(&self, other: &ArrayImmutable) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl PartialOrd for ArrayImmutable[src]
impl PartialOrd for ArrayImmutablefn partial_cmp(&self, other: &ArrayImmutable) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &ArrayImmutable) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &Rhs) -> bool1.0.0[src]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Clone for ArrayImmutable[src]
impl Clone for ArrayImmutablefn clone(&self) -> ArrayImmutable[src]
fn clone(&self) -> ArrayImmutableReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Debug for ArrayImmutable[src]
impl Debug for ArrayImmutablefn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Array for ArrayImmutable[src]
impl Array for ArrayImmutablefn values_as_slice(&self) -> &[Value][src]
fn values_as_slice(&self) -> &[Value]ⓘImportant traits for Iter<'a, T>fn values_iter(&self) -> Iter<Value>[src]
fn values_iter(&self) -> Iter<Value>fn values_clone(&self) -> StdVec<Value>[src]
fn values_clone(&self) -> StdVec<Value>fn values_is_empty(&self) -> bool[src]
fn values_is_empty(&self) -> boolfn values_is_not_empty(&self) -> bool[src]
fn values_is_not_empty(&self) -> boolfn values_length(&self) -> usize[src]
fn values_length(&self) -> usizeAuto Trait Implementations
impl !Send for ArrayImmutable
impl !Send for ArrayImmutableimpl !Sync for ArrayImmutable
impl !Sync for ArrayImmutable