Struct vonuvoli_scheme::internals::values::ArrayMutable [−][src]
pub struct ArrayMutable(_);
Methods
impl ArrayMutable[src]
impl ArrayMutablepub fn from_rc(rc: StdRc<StdBox<[Value]>>) -> ArrayMutable[src]
pub fn from_rc(rc: StdRc<StdBox<[Value]>>) -> ArrayMutablepub fn clone_rc(rc: &StdRc<StdBox<[Value]>>) -> ArrayMutable[src]
pub fn clone_rc(rc: &StdRc<StdBox<[Value]>>) -> ArrayMutablepub fn is_self(&self, other: &ArrayMutable) -> bool[src]
pub fn is_self(&self, other: &ArrayMutable) -> boolpub fn array_ref(&self) -> Outcome<ArrayRef>[src]
pub fn array_ref(&self) -> Outcome<ArrayRef>pub fn values_rc_clone(&self) -> StdRc<StdRefCell<ArrayMutableInternals>>[src]
pub fn values_rc_clone(&self) -> StdRc<StdRefCell<ArrayMutableInternals>>pub fn values_ref_mut(&self) -> Outcome<StdRefMut<StdVec<Value>>>[src]
pub fn values_ref_mut(&self) -> Outcome<StdRefMut<StdVec<Value>>>pub fn to_immutable(&self) -> Outcome<ArrayImmutable>[src]
pub fn to_immutable(&self) -> Outcome<ArrayImmutable>Trait Implementations
impl StdAsRef<ArrayMutable> for ArrayMutable[src]
impl StdAsRef<ArrayMutable> for ArrayMutablefn as_ref(&self) -> &ArrayMutable[src]
fn as_ref(&self) -> &ArrayMutablePerforms the conversion.
impl StdFrom<ArrayMutable> for Value[src]
impl StdFrom<ArrayMutable> for Valuefn from(value: ArrayMutable) -> Value[src]
fn from(value: ArrayMutable) -> ValuePerforms the conversion.
impl StdFrom<ArrayMutable> for StdBox<Value>[src]
impl StdFrom<ArrayMutable> for StdBox<Value>ⓘImportant traits for Box<R>fn from(value: ArrayMutable) -> StdBox<Value>[src]
fn from(value: ArrayMutable) -> StdBox<Value>Performs the conversion.
impl StdInto0<Outcome<Value>> for ArrayMutable[src]
impl StdInto0<Outcome<Value>> for ArrayMutableimpl StdFrom<ArrayMutable> for Expression[src]
impl StdFrom<ArrayMutable> for Expressionfn from(value: ArrayMutable) -> Expression[src]
fn from(value: ArrayMutable) -> ExpressionPerforms the conversion.
impl StdFrom<ArrayMutable> for StdBox<Expression>[src]
impl StdFrom<ArrayMutable> for StdBox<Expression>ⓘImportant traits for Box<R>fn from(value: ArrayMutable) -> StdBox<Expression>[src]
fn from(value: ArrayMutable) -> StdBox<Expression>Performs the conversion.
impl StdInto0<Outcome<Expression>> for ArrayMutable[src]
impl StdInto0<Outcome<Expression>> for ArrayMutablefn into_0(self) -> Outcome<Expression>[src]
fn into_0(self) -> Outcome<Expression>impl StdTryFrom<Value> for ArrayMutable[src]
impl StdTryFrom<Value> for ArrayMutabletype Error = Error
try_from)The type returned in the event of a conversion error.
fn try_from(value: Value) -> Result<ArrayMutable, Error>[src]
fn try_from(value: Value) -> Result<ArrayMutable, Error>try_from)Performs the conversion.
impl StdTryAsRef0<ArrayMutable> for Value[src]
impl StdTryAsRef0<ArrayMutable> for Valuetype Error = Error
fn try_as_ref_0(&self) -> Result<&ArrayMutable, Error>[src]
fn try_as_ref_0(&self) -> Result<&ArrayMutable, Error>impl StdTryFrom<StdBox<Value>> for ArrayMutable[src]
impl StdTryFrom<StdBox<Value>> for ArrayMutabletype Error = Error
try_from)The type returned in the event of a conversion error.
fn try_from(value: StdBox<Value>) -> Result<ArrayMutable, Error>[src]
fn try_from(value: StdBox<Value>) -> Result<ArrayMutable, Error>try_from)Performs the conversion.
impl StdTryFrom<Expression> for ArrayMutable[src]
impl StdTryFrom<Expression> for ArrayMutabletype Error = Error
try_from)The type returned in the event of a conversion error.
fn try_from(value: Expression) -> Result<ArrayMutable, Error>[src]
fn try_from(value: Expression) -> Result<ArrayMutable, Error>try_from)Performs the conversion.
impl StdTryFrom<StdBox<Expression>> for ArrayMutable[src]
impl StdTryFrom<StdBox<Expression>> for ArrayMutabletype Error = Error
try_from)The type returned in the event of a conversion error.
fn try_from(value: StdBox<Expression>) -> Result<ArrayMutable, Error>[src]
fn try_from(value: StdBox<Expression>) -> Result<ArrayMutable, Error>try_from)Performs the conversion.
impl Display for ArrayMutable[src]
impl Display for ArrayMutablefn fmt(&self, formatter: &mut Formatter) -> Result[src]
fn fmt(&self, formatter: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl HashValue for ArrayMutable[src]
impl HashValue for ArrayMutableimpl Hash for ArrayMutable[src]
impl Hash for ArrayMutablefn hash<Hasher: Hasher>(&self, hasher: &mut Hasher)[src]
fn hash<Hasher: Hasher>(&self, hasher: &mut Hasher)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Eq for ArrayMutable[src]
impl Eq for ArrayMutableimpl PartialEq for ArrayMutable[src]
impl PartialEq for ArrayMutablefn eq(&self, other: &ArrayMutable) -> bool[src]
fn eq(&self, other: &ArrayMutable) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Ord for ArrayMutable[src]
impl Ord for ArrayMutablefn cmp(&self, other: &ArrayMutable) -> Ordering[src]
fn cmp(&self, other: &ArrayMutable) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl PartialOrd for ArrayMutable[src]
impl PartialOrd for ArrayMutablefn partial_cmp(&self, other: &ArrayMutable) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &ArrayMutable) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &Rhs) -> bool1.0.0[src]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Clone for ArrayMutable[src]
impl Clone for ArrayMutablefn clone(&self) -> ArrayMutable[src]
fn clone(&self) -> ArrayMutableReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Debug for ArrayMutable[src]
impl Debug for ArrayMutableAuto Trait Implementations
impl !Send for ArrayMutable
impl !Send for ArrayMutableimpl !Sync for ArrayMutable
impl !Sync for ArrayMutable