Struct vonuvoli_scheme::internals::values::StringMutable [−][src]
pub struct StringMutable(_);
Methods
impl StringMutable[src]
impl StringMutablepub fn from_rc(rc: StdRc<StdBox<str>>) -> StringMutable[src]
pub fn from_rc(rc: StdRc<StdBox<str>>) -> StringMutablepub fn clone_rc(rc: &StdRc<StdBox<str>>) -> StringMutable[src]
pub fn clone_rc(rc: &StdRc<StdBox<str>>) -> StringMutablepub fn is_self(&self, other: &StringMutable) -> bool[src]
pub fn is_self(&self, other: &StringMutable) -> boolpub fn string_ref(&self) -> Outcome<StringRef>[src]
pub fn string_ref(&self) -> Outcome<StringRef>pub fn string_rc_clone(&self) -> StdRc<StdRefCell<StringMutableInternals>>[src]
pub fn string_rc_clone(&self) -> StdRc<StdRefCell<StringMutableInternals>>pub fn string_ref_mut(&self) -> Outcome<StdRefMut<StdString>>[src]
pub fn string_ref_mut(&self) -> Outcome<StdRefMut<StdString>>pub fn to_immutable(&self) -> Outcome<StringImmutable>[src]
pub fn to_immutable(&self) -> Outcome<StringImmutable>Trait Implementations
impl StdAsRef<StringMutable> for StringMutable[src]
impl StdAsRef<StringMutable> for StringMutablefn as_ref(&self) -> &StringMutable[src]
fn as_ref(&self) -> &StringMutablePerforms the conversion.
impl StdFrom<StringMutable> for Value[src]
impl StdFrom<StringMutable> for Valuefn from(value: StringMutable) -> Value[src]
fn from(value: StringMutable) -> ValuePerforms the conversion.
impl StdFrom<StringMutable> for StdBox<Value>[src]
impl StdFrom<StringMutable> for StdBox<Value>ⓘImportant traits for Box<R>fn from(value: StringMutable) -> StdBox<Value>[src]
fn from(value: StringMutable) -> StdBox<Value>Performs the conversion.
impl StdInto0<Outcome<Value>> for StringMutable[src]
impl StdInto0<Outcome<Value>> for StringMutableimpl StdFrom<StringMutable> for Expression[src]
impl StdFrom<StringMutable> for Expressionfn from(value: StringMutable) -> Expression[src]
fn from(value: StringMutable) -> ExpressionPerforms the conversion.
impl StdFrom<StringMutable> for StdBox<Expression>[src]
impl StdFrom<StringMutable> for StdBox<Expression>ⓘImportant traits for Box<R>fn from(value: StringMutable) -> StdBox<Expression>[src]
fn from(value: StringMutable) -> StdBox<Expression>Performs the conversion.
impl StdInto0<Outcome<Expression>> for StringMutable[src]
impl StdInto0<Outcome<Expression>> for StringMutablefn into_0(self) -> Outcome<Expression>[src]
fn into_0(self) -> Outcome<Expression>impl StdTryFrom<Value> for StringMutable[src]
impl StdTryFrom<Value> for StringMutabletype Error = Error
try_from)The type returned in the event of a conversion error.
fn try_from(value: Value) -> Result<StringMutable, Error>[src]
fn try_from(value: Value) -> Result<StringMutable, Error>try_from)Performs the conversion.
impl StdTryAsRef0<StringMutable> for Value[src]
impl StdTryAsRef0<StringMutable> for Valuetype Error = Error
fn try_as_ref_0(&self) -> Result<&StringMutable, Error>[src]
fn try_as_ref_0(&self) -> Result<&StringMutable, Error>impl StdTryFrom<StdBox<Value>> for StringMutable[src]
impl StdTryFrom<StdBox<Value>> for StringMutabletype Error = Error
try_from)The type returned in the event of a conversion error.
fn try_from(value: StdBox<Value>) -> Result<StringMutable, Error>[src]
fn try_from(value: StdBox<Value>) -> Result<StringMutable, Error>try_from)Performs the conversion.
impl StdTryFrom<Expression> for StringMutable[src]
impl StdTryFrom<Expression> for StringMutabletype Error = Error
try_from)The type returned in the event of a conversion error.
fn try_from(value: Expression) -> Result<StringMutable, Error>[src]
fn try_from(value: Expression) -> Result<StringMutable, Error>try_from)Performs the conversion.
impl StdTryFrom<StdBox<Expression>> for StringMutable[src]
impl StdTryFrom<StdBox<Expression>> for StringMutabletype Error = Error
try_from)The type returned in the event of a conversion error.
fn try_from(value: StdBox<Expression>) -> Result<StringMutable, Error>[src]
fn try_from(value: StdBox<Expression>) -> Result<StringMutable, Error>try_from)Performs the conversion.
impl StdFrom<StdString> for StringMutable[src]
impl StdFrom<StdString> for StringMutablefn from(value: StdString) -> StringMutable[src]
fn from(value: StdString) -> StringMutablePerforms the conversion.
impl StdFrom<&'static str> for StringMutable[src]
impl StdFrom<&'static str> for StringMutablefn from(value: &'static str) -> StringMutable[src]
fn from(value: &'static str) -> StringMutablePerforms the conversion.
impl<'a> StdTryFrom<&'a StringMutable> for BytesSliceRef<'a>[src]
impl<'a> StdTryFrom<&'a StringMutable> for BytesSliceRef<'a>type Error = Error
try_from)The type returned in the event of a conversion error.
fn try_from(value: &'a StringMutable) -> Result<BytesSliceRef<'a>, Self::Error>[src]
fn try_from(value: &'a StringMutable) -> Result<BytesSliceRef<'a>, Self::Error>try_from)Performs the conversion.
impl Display for StringMutable[src]
impl Display for StringMutablefn fmt(&self, formatter: &mut Formatter) -> Result[src]
fn fmt(&self, formatter: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl HashValue for StringMutable[src]
impl HashValue for StringMutableimpl Hash for StringMutable[src]
impl Hash for StringMutablefn hash<Hasher: Hasher>(&self, hasher: &mut Hasher)[src]
fn hash<Hasher: Hasher>(&self, hasher: &mut Hasher)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Eq for StringMutable[src]
impl Eq for StringMutableimpl PartialEq for StringMutable[src]
impl PartialEq for StringMutablefn eq(&self, other: &StringMutable) -> bool[src]
fn eq(&self, other: &StringMutable) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Ord for StringMutable[src]
impl Ord for StringMutablefn cmp(&self, other: &StringMutable) -> Ordering[src]
fn cmp(&self, other: &StringMutable) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl PartialOrd for StringMutable[src]
impl PartialOrd for StringMutablefn partial_cmp(&self, other: &StringMutable) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &StringMutable) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &Rhs) -> bool1.0.0[src]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Clone for StringMutable[src]
impl Clone for StringMutablefn clone(&self) -> StringMutable[src]
fn clone(&self) -> StringMutableReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Debug for StringMutable[src]
impl Debug for StringMutableAuto Trait Implementations
impl !Send for StringMutable
impl !Send for StringMutableimpl !Sync for StringMutable
impl !Sync for StringMutable