Struct vonuvoli_scheme::internals::values_strings::StringImmutable [−][src]
pub struct StringImmutable(_);
Methods
impl StringImmutable[src]
impl StringImmutablepub fn from_rc(rc: StdRc<StdBox<str>>) -> StringImmutable[src]
pub fn from_rc(rc: StdRc<StdBox<str>>) -> StringImmutablepub fn clone_rc(rc: &StdRc<StdBox<str>>) -> StringImmutable[src]
pub fn clone_rc(rc: &StdRc<StdBox<str>>) -> StringImmutablepub fn is_self(&self, other: &StringImmutable) -> bool[src]
pub fn is_self(&self, other: &StringImmutable) -> boolpub fn string_ref(&self) -> StringRef[src]
pub fn string_ref(&self) -> StringRefpub fn string_rc_clone(&self) -> StdRc<StdBox<str>>[src]
pub fn string_rc_clone(&self) -> StdRc<StdBox<str>>pub fn to_mutable(&self) -> StringMutable[src]
pub fn to_mutable(&self) -> StringMutableTrait Implementations
impl StdAsRef<StringImmutable> for StringImmutable[src]
impl StdAsRef<StringImmutable> for StringImmutablefn as_ref(&self) -> &StringImmutable[src]
fn as_ref(&self) -> &StringImmutablePerforms the conversion.
impl StdFrom<StringImmutable> for Value[src]
impl StdFrom<StringImmutable> for Valuefn from(value: StringImmutable) -> Value[src]
fn from(value: StringImmutable) -> ValuePerforms the conversion.
impl StdFrom<StringImmutable> for StdBox<Value>[src]
impl StdFrom<StringImmutable> for StdBox<Value>ⓘImportant traits for Box<R>fn from(value: StringImmutable) -> StdBox<Value>[src]
fn from(value: StringImmutable) -> StdBox<Value>Performs the conversion.
impl StdInto0<Outcome<Value>> for StringImmutable[src]
impl StdInto0<Outcome<Value>> for StringImmutableimpl StdFrom<StringImmutable> for Expression[src]
impl StdFrom<StringImmutable> for Expressionfn from(value: StringImmutable) -> Expression[src]
fn from(value: StringImmutable) -> ExpressionPerforms the conversion.
impl StdFrom<StringImmutable> for StdBox<Expression>[src]
impl StdFrom<StringImmutable> for StdBox<Expression>ⓘImportant traits for Box<R>fn from(value: StringImmutable) -> StdBox<Expression>[src]
fn from(value: StringImmutable) -> StdBox<Expression>Performs the conversion.
impl StdInto0<Outcome<Expression>> for StringImmutable[src]
impl StdInto0<Outcome<Expression>> for StringImmutablefn into_0(self) -> Outcome<Expression>[src]
fn into_0(self) -> Outcome<Expression>impl StdTryFrom<Value> for StringImmutable[src]
impl StdTryFrom<Value> for StringImmutabletype Error = Error
try_from)The type returned in the event of a conversion error.
fn try_from(value: Value) -> Result<StringImmutable, Error>[src]
fn try_from(value: Value) -> Result<StringImmutable, Error>try_from)Performs the conversion.
impl StdTryAsRef0<StringImmutable> for Value[src]
impl StdTryAsRef0<StringImmutable> for Valuetype Error = Error
fn try_as_ref_0(&self) -> Result<&StringImmutable, Error>[src]
fn try_as_ref_0(&self) -> Result<&StringImmutable, Error>impl StdTryFrom<StdBox<Value>> for StringImmutable[src]
impl StdTryFrom<StdBox<Value>> for StringImmutabletype Error = Error
try_from)The type returned in the event of a conversion error.
fn try_from(value: StdBox<Value>) -> Result<StringImmutable, Error>[src]
fn try_from(value: StdBox<Value>) -> Result<StringImmutable, Error>try_from)Performs the conversion.
impl StdTryFrom<Expression> for StringImmutable[src]
impl StdTryFrom<Expression> for StringImmutabletype Error = Error
try_from)The type returned in the event of a conversion error.
fn try_from(value: Expression) -> Result<StringImmutable, Error>[src]
fn try_from(value: Expression) -> Result<StringImmutable, Error>try_from)Performs the conversion.
impl StdTryFrom<StdBox<Expression>> for StringImmutable[src]
impl StdTryFrom<StdBox<Expression>> for StringImmutabletype Error = Error
try_from)The type returned in the event of a conversion error.
fn try_from(value: StdBox<Expression>) -> Result<StringImmutable, Error>[src]
fn try_from(value: StdBox<Expression>) -> Result<StringImmutable, Error>try_from)Performs the conversion.
impl StdFrom<StdString> for StringImmutable[src]
impl StdFrom<StdString> for StringImmutablefn from(value: StdString) -> StringImmutable[src]
fn from(value: StdString) -> StringImmutablePerforms the conversion.
impl StdFrom<&'static str> for StringImmutable[src]
impl StdFrom<&'static str> for StringImmutablefn from(value: &'static str) -> StringImmutable[src]
fn from(value: &'static str) -> StringImmutablePerforms the conversion.
impl<'a> StdFrom<&'a StringImmutable> for BytesSliceRef<'a>[src]
impl<'a> StdFrom<&'a StringImmutable> for BytesSliceRef<'a>fn from(value: &'a StringImmutable) -> BytesSliceRef<'a>[src]
fn from(value: &'a StringImmutable) -> BytesSliceRef<'a>Performs the conversion.
impl Display for StringImmutable[src]
impl Display for StringImmutablefn fmt(&self, formatter: &mut Formatter) -> Result[src]
fn fmt(&self, formatter: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl HashValue for StringImmutable[src]
impl HashValue for StringImmutableimpl Hash for StringImmutable[src]
impl Hash for StringImmutablefn hash<Hasher: Hasher>(&self, hasher: &mut Hasher)[src]
fn hash<Hasher: Hasher>(&self, hasher: &mut Hasher)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Eq for StringImmutable[src]
impl Eq for StringImmutableimpl PartialEq for StringImmutable[src]
impl PartialEq for StringImmutablefn eq(&self, other: &StringImmutable) -> bool[src]
fn eq(&self, other: &StringImmutable) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Ord for StringImmutable[src]
impl Ord for StringImmutablefn cmp(&self, other: &StringImmutable) -> Ordering[src]
fn cmp(&self, other: &StringImmutable) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl PartialOrd for StringImmutable[src]
impl PartialOrd for StringImmutablefn partial_cmp(&self, other: &StringImmutable) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &StringImmutable) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &Rhs) -> bool1.0.0[src]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Clone for StringImmutable[src]
impl Clone for StringImmutablefn clone(&self) -> StringImmutable[src]
fn clone(&self) -> StringImmutableReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Debug for StringImmutable[src]
impl Debug for StringImmutablefn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl String for StringImmutable[src]
impl String for StringImmutablefn string_as_str(&self) -> &str[src]
fn string_as_str(&self) -> &strfn string_as_bytes(&self) -> &[u8][src]
fn string_as_bytes(&self) -> &[u8]ⓘImportant traits for Chars<'a>fn string_chars(&self) -> Chars[src]
fn string_chars(&self) -> Charsfn string_clone(&self) -> StdString[src]
fn string_clone(&self) -> StdStringfn string_is_empty(&self) -> bool[src]
fn string_is_empty(&self) -> boolfn string_is_not_empty(&self) -> bool[src]
fn string_is_not_empty(&self) -> boolfn string_eq(&self, other: &str) -> bool[src]
fn string_eq(&self, other: &str) -> boolfn string_utf8_bytes_count(&self) -> usize[src]
fn string_utf8_bytes_count(&self) -> usizefn string_chars_count_compute(&self) -> usize[src]
fn string_chars_count_compute(&self) -> usizefn string_char_at_compute(&self, index: usize) -> Option<char>[src]
fn string_char_at_compute(&self, index: usize) -> Option<char>Auto Trait Implementations
impl !Send for StringImmutable
impl !Send for StringImmutableimpl !Sync for StringImmutable
impl !Sync for StringImmutable